util

package
v1.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 12, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DetectFileMIME

func DetectFileMIME(file *multipart.FileHeader) (string, error)

DetectFileMIME reads the first 512 bytes of a multipart file to detect its real MIME type.

func MIMEToExt

func MIMEToExt(mimeType string) (string, error)

MIMEToExt returns a file extension for the given MIME type.

Types

This section is empty.

Jump to